@@ -120,7 +120,7 @@ QVariant FunctionListModel::data(const QModelIndex &index, int role) const
 Qt::ItemFlags FunctionListModel::flags(const QModelIndex &index) const
 {
     if (!index.isValid())
-        return nullptr;
+        return Qt::NoItemFlags;
 
     return Qt::ItemIsEnabled | Qt::ItemIsSelectable;
 }
